@@ -1,6 +1,41 @@
+# MIT License
+
+# Copyright (c) 2024 Mr-Major-K
+
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
+
+"""
+A class for handling log messages in files.
+
+This class inherits from the Handler class and implements specific
+methods for formatting and outputting log messages to files. It supports
+the creation of log files in a specified directory, automatic file rotation
+based on the current date, and allows customization of the formatting
+string. The FileHandler ensures that log messages are stored persistently
+and can be reviewed later for debugging or auditing purposes.
+"""
+
 import os
+from datetime import timedelta
 from datetime import datetime
 
+
 from .handler import Handler
 
 
@@ -15,9 +50,14 @@ class FileHandler(Handler):
     string. The FileHandler ensures that log messages are stored persistently
     and can be reviewed later for debugging or auditing purposes.
     """
-    def __init__(self, name: str, path: str = "logs",
+
+    def __init__(self,
+                 name: str,
+                 path: str = "logs",
                  logformat_string: str = "%(asctime)s: [%(loggername)s]: \
-[%(loglevel)s]: %(message)s") -> None:
+[%(loglevel)s]: %(message)s",
+                 new_file_after: timedelta = timedelta(days=1)
+                 ) -> None:
         """
         Initializes the FileHandler with the given name, log path, and log
             format string.
